# remirepo/fedora spec file for php-zumba-json-serializer
#
# Copyright (c) 2021 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%bcond_without       tests

%global gh_commit    d91d5a22bbbacbb1d6ad23302137a90e9a7dafd5
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     zumba
%global gh_project   json-serializer
%global ns_vendor    Zumba
%global ns_project   JsonSerializer
%global major        %nil

Name:           php-%{gh_owner}-%{gh_project}%{major}
Version:        3.0.1
Release:        1%{?dist}
Summary:        Serialize PHP variables

License:        MIT
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{name}-%{version}-%{?gh_short}.tar.gz

BuildArch:      noarch
%if %{with tests}
BuildRequires:  php(language) >= 7.0
BuildRequires:  php-date
BuildRequires:  php-json
BuildRequires:  php-mbstring
BuildRequires:  php-pcre
BuildRequires:  php-reflection
BuildRequires:  php-spl
# For tests, from composer.json "require-dev": {
#        "phpunit/phpunit": ">=6.0 <10.0"
BuildRequires:  phpunit9
%global phpunit %{_bindir}/phpunit9
%endif
# For autoloader
BuildRequires:  php-fedora-autoloader-devel

# From composer.json, "require": {
#        "php": ">=7.0.0",
#        "ext-mbstring": "*"
Requires:       php(language) >= 7.0
Requires:       php-mbstring
# From phpcompatinfo report for 3.0.1
Requires:       php-json
Requires:       php-pcre
Requires:       php-reflection
Requires:       php-spl
# For generated autoloader
Requires:       php-composer(fedora/autoloader)

# Composer
Provides:       php-composer(%{gh_owner}/%{gh_project}) = %{version}


%description
This is a library to serialize PHP variables in JSON format. It is similar
of the serialize() function in PHP, but the output is a string JSON encoded.
You can also unserialize the JSON generated by this tool and have you PHP
content back.

Autoloader: %{_datadir}/php/%{ns_vendor}/%{ns_project}%{major}/autoload.php


%prep
%setup -q -n %{gh_project}-%{gh_commit}


%build
: Create autoloader
phpab --template fedora --output src/%{ns_project}/autoload.php src


%install
: Library
mkdir -p      %{buildroot}%{_datadir}/php/
cp -pr src    %{buildroot}%{_datadir}/php/%{ns_vendor}


%check
%if %{with tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require '%{buildroot}%{_datadir}/php/%{ns_vendor}/%{ns_project}%{major}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('%{ns_vendor}\\%{ns_project}\\Test\\', dirname(__DIR__).'/tests');
EOF

ret=0
for cmdarg in "php %{phpunit}" php74 php80 php81; do
   if which $cmdarg; then
      set $cmdarg
      $1 ${2:-%{_bindir}/phpunit9} \
          --bootstrap vendor/autoload.php \
          --no-coverage \
          --verbose || ret=1
   fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
%license LICENSE
%doc composer.json
%doc README.md
%dir %{_datadir}/php/%{ns_vendor}
     %{_datadir}/php/%{ns_vendor}/%{ns_project}%{major}


%changelog
* Thu Dec  9 2021 Remi Collet <remi@remirepo.net> - 3.0.1-1
- initial package
